.. toctree::
   :maxdepth: 2

Transport tweaks
----------------

.. include:: /../../examples/v1arch/asyncore/agent/ntforg/send-trap-over-ipv4-and-ipv6.py
   :start-after: """
   :end-before: """#

.. literalinclude:: /../../examples/v1arch/asyncore/agent/ntforg/send-trap-over-ipv4-and-ipv6.py
   :start-after: """#
   :language: python

:download:`Download</../../examples/v1arch/asyncore/agent/ntforg/send-trap-over-ipv4-and-ipv6.py>` script.


.. include:: /../../examples/v1arch/asyncore/agent/ntforg/send-inform-over-ipv4-and-ipv6.py
   :start-after: """
   :end-before: """#

.. literalinclude:: /../../examples/v1arch/asyncore/agent/ntforg/send-inform-over-ipv4-and-ipv6.py
   :start-after: """#
   :language: python

:download:`Download</../../examples/v1arch/asyncore/agent/ntforg/send-inform-over-ipv4-and-ipv6.py>` script.


See also: :doc:`library reference </docs/api-reference>`.
